"""
    Enterprise Mission Assurance Support Service (eMASS)

    The Enterprise Mission Assurance Support Service (eMASS) Representational State Transfer (REST) Application Programming Interface (API) enables users to perform assessments and complete actions associated with system records.   <strong>Register External Application (that use the eMASS API)</strong></br> New users will need to [register](https://nisp.emass.apps.mil/Content/Help/jobaids/eMASS_OT_NewUser_Job_Aid.pdf) an API key with the eMASS development team prior to accessing the site for the first time. The eMASS REST API  requires a client certificate (SSL/TLS, DoD PKI only). Use the `Registration` endpoint to register the client certificate.</br></br>  Every call to the eMASS REST API will require the use of the agreed upon public key certificate and API key.  The API key must be provided in the request header for all endpoint calls (api-key). If the service receives an untrusted certificate or API key, a 401 error response code will be returned along with an error message.</br></br>  <strong>Available Request Headers</strong></br> <table>   <tr>     <th align=left>key</th>     <th align=left>Example Value</th>     <th align=left>Description</th>   </tr>   <tr>     <td>`api-key`</td>     <td>api-key-provided-by-emass</td>     <td>This API key must be provided in the request header for all endpoint calls</td>   </tr>   <tr>     <td>`user-uid`</td>     <td>USER.UID.KEY</td>     <td>This User unique identifier key must be provided in the request header for all PUT, POST, and DELETE endpoint calls</td>   </tr>   <tr>     <td></td><td></td>     <td>       Note: For DoD users this is the DoD ID Number (EIDIPI) on their DoD CAC     </td>   </tr> </table>  </br><strong>Approve API Client for Actionable Requests</strong></br> Users are required to log-in to eMASS and grant permissions for a client to update data within eMASS on their behalf. This is only required for actionable requests (PUT, POST, DELETE). The Registration Endpoint and all GET requests can be accessed without completing this process with the correct permissions. Please note that leaving a field parameter blank (for PUT/POST requests) has the potential to clear information in the active eMASS records.  To establish an account with eMASS and/or acquire an api-key/user-uid, contact one of the listed POC:   # noqa: E501

    The version of the OpenAPI document: v3.4
    Contact: disa.meade.id.mbx.emass-tier-iii-support@mail.mil
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from emass_client.api_client import ApiClient, Endpoint as _Endpoint
from emass_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from emass_client.model.response400 import Response400
from emass_client.model.response401 import Response401
from emass_client.model.response403 import Response403
from emass_client.model.response404 import Response404
from emass_client.model.response405 import Response405
from emass_client.model.response490 import Response490
from emass_client.model.response500 import Response500
from emass_client.model.system_response import SystemResponse
from emass_client.model.systems_response import SystemsResponse


class SystemsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_system_endpoint = _Endpoint(
            settings={
                'response_type': (SystemResponse,),
                'auth': [
                    'apiKey',
                    'mockType',
                    'userId'
                ],
                'endpoint_path': '/api/systems/{systemId}',
                'operation_id': 'get_system',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_id',
                    'include_package',
                    'policy',
                ],
                'required': [
                    'system_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'policy',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('policy',): {

                        "DIACAP": "diacap",
                        "RMF": "rmf",
                        "REPORTING": "reporting"
                    },
                },
                'openapi_types': {
                    'system_id':
                        (int,),
                    'include_package':
                        (bool,),
                    'policy':
                        (str,),
                },
                'attribute_map': {
                    'system_id': 'systemId',
                    'include_package': 'includePackage',
                    'policy': 'policy',
                },
                'location_map': {
                    'system_id': 'path',
                    'include_package': 'query',
                    'policy': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_systems_endpoint = _Endpoint(
            settings={
                'response_type': (SystemsResponse,),
                'auth': [
                    'apiKey',
                    'mockType',
                    'userId'
                ],
                'endpoint_path': '/api/systems',
                'operation_id': 'get_systems',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'include_package',
                    'registration_type',
                    'ditpr_id',
                    'coams_id',
                    'policy',
                    'include_ditpr_metrics',
                    'include_decommissioned',
                    'reports_for_scorecard',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'policy',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('policy',): {

                        "DIACAP": "diacap",
                        "RMF": "rmf",
                        "REPORTING": "reporting"
                    },
                },
                'openapi_types': {
                    'include_package':
                        (bool,),
                    'registration_type':
                        (str,),
                    'ditpr_id':
                        (str,),
                    'coams_id':
                        (str,),
                    'policy':
                        (str,),
                    'include_ditpr_metrics':
                        (bool,),
                    'include_decommissioned':
                        (bool,),
                    'reports_for_scorecard':
                        (bool,),
                },
                'attribute_map': {
                    'include_package': 'includePackage',
                    'registration_type': 'registrationType',
                    'ditpr_id': 'ditprId',
                    'coams_id': 'coamsId',
                    'policy': 'policy',
                    'include_ditpr_metrics': 'includeDitprMetrics',
                    'include_decommissioned': 'includeDecommissioned',
                    'reports_for_scorecard': 'reportsForScorecard',
                },
                'location_map': {
                    'include_package': 'query',
                    'registration_type': 'query',
                    'ditpr_id': 'query',
                    'coams_id': 'query',
                    'policy': 'query',
                    'include_ditpr_metrics': 'query',
                    'include_decommissioned': 'query',
                    'reports_for_scorecard': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_system(
        self,
        system_id,
        **kwargs
    ):
        """Get system information for a specific system  # noqa: E501

        Returns the system matching provided parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_system(system_id, async_req=True)
        >>> result = thread.get()

        Args:
            system_id (int): **System Id**: The unique system record identifier.

        Keyword Args:
            include_package (bool): **Include Package**:  Indicates if additional packages information is retrieved for queried system.. [optional] if omitted the server will use the default value of True
            policy (str): **System Policy**: Filter query by system policy. If no value is specified and more than one policy is available, the default return is the RMF policy information.. [optional] if omitted the server will use the default value of "rmf"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SystemResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['system_id'] = \
            system_id
        return self.get_system_endpoint.call_with_http_info(**kwargs)

    def get_systems(
        self,
        **kwargs
    ):
        """Get system information  # noqa: E501

        Returns all system(s) that match the query parameters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_systems(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            include_package (bool): **Include Package**:  Indicates if additional packages information is retrieved for queried system.. [optional] if omitted the server will use the default value of True
            registration_type (str): **Registration Type**: Filter record by selected registration type (single value or comma delimited values).  *Available values:* assessAndAuthorize, assessOnly, guest, regular, functional, cloudServiceProvider, commonControlProvider  . [optional] if omitted the server will use the default value of "regular"
            ditpr_id (str): **DITPR ID**: Filter query by DoD Information Technology (IT) Portfolio Repository (DITPR).. [optional]
            coams_id (str): **COAMS ID**: Filter query by Cyber Operational Attributes Management System (COAMS).. [optional]
            policy (str): **System Policy**: Filter query by system policy. If no value is specified and more than one policy is available, the default return is the RMF policy information.. [optional] if omitted the server will use the default value of "rmf"
            include_ditpr_metrics (bool): **Include DITPR**: Indicates if DITPR metrics are retrieved. This query string parameter can only be used in conjunction with the following parameters:<br>   <ul>     <li>registrationType</li>     <li>policy</li>   </ul>. [optional] if omitted the server will use the default value of False
            include_decommissioned (bool): **Include Decommissioned Systems**: Indicates if decommissioned systems are retrieved. If no value is specified, the default returns true to include decommissioned systems.. [optional] if omitted the server will use the default value of True
            reports_for_scorecard (bool): **DoD Cyber Hygiene Scorecard**: Indicates if the system reports to the DoD Cyber Hygiene Scorecard.. [optional] if omitted the server will use the default value of True
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            SystemsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_systems_endpoint.call_with_http_info(**kwargs)

